;; All lines should end in a newline
(setq require-final-newline t)

;; disable tabs
(setq tab-width 4)
(setq-default indent-tabs-mode nil)

;; Cleanup whitespace before saves.
(add-hook 'before-save-hook '(lambda ()
                               (if af-cleanup-whitespace (whitespace-cleanup))))
(setq whitespace-chars (quote (tabs spaces trailing lines newline empty)))

;; Disable that startup screen
(setq inhibit-startup-message t)

;; Basically everything I do is in version control, stop saving backup files
(setq make-backup-files nil)

;; Set some pretty colors that are gentler on my eyes
(setq default-frame-alist
      '((width . 80)
        (cursor-color . "white")
        (cursor-type . box)
        (foreground-color . "white")
        (background-color . "black")
        )
      )

;; tell ipython we have a dark background
(setq py-python-command-args (quote ("-i")))

; always highlight matching paren
(show-paren-mode 1)

;; Automatically revert unedited files that change on the underlying
;; system.
(global-auto-revert-mode)

;; I like dots in my nose output
(setq nose-use-verbose nil)

;; no toolbar
(setq tool-bar-mode nil)
(tool-bar-mode 0)

;; scrollbars, but on the right, not the left
(set-scroll-bar-mode 'right)

;; Command is meta in OS X.
(setq ns-command-modifier (quote meta))

;; Don't popup new frames for opened files
(setq ns-pop-up-frames nil)

; cause imenu to always rescan the buffer (for textmate-goto-symbol)
(setq imenu-auto-rescan t)
;; better uniquify from http://metapundit.net/sections/blog/emacs_and_django
(require 'uniquify)
(setq uniquify-buffer-name-style 'reverse)
(setq uniquify-separator "/")
(setq uniquify-after-kill-buffer-p t)
(setq uniquify-ignore-buffers-re "^\\*")
(setq hg-outgoing-repository "")
(setq hg-incoming-repository "")
; so that Cmd+H won't activate Hide Current
; App and Cmd+Shift+q won't logout user.
(setq mac-pass-command-to-system nil)

(cond
 ((eq window-system 'ns) ;; OS X
  (set-face-attribute 'default nil :height 120))
 (t ;; everywhere else
  (set-face-attribute 'default nil :height 100)))

;; use y or n instead of yes or no
(fset 'yes-or-no-p 'y-or-n-p)

;; customized theme faces
(custom-set-faces
 '(magit-diff-add ((t (:foreground "DarkGreen"))) 'now)
 '(magit-item-highlight ((t (:background "grey19"))) 'now))
